(ns reagent-test.core
  (:require [cljs.core.async :refer [<! go]]
            [reagent-test.ncbi :refer [ncbi-search]]
            [reagent.dom :as d]))

;; -------------------------
;; Component data (custom)

(def action-btns [{:text "tools" :action #(js/console.log "hi")}
                  {:text "search" :action #((go (let [res (<! (ncbi-search "pubmed" "science[journal]+AND+breast+cancer+AND+2008[pdat]"))]
                                                  (js/console.log res))))}
                  {:text "help" :action #(js/console.log "test4")}])

;; -------------------------
;; Menus

(defn dropdown-or-action
  "Render dropdown menu for an action button/menu"
  [btn-item is-dropdown]
  [:button {:class (if is-dropdown "menu-button" "")}
   :text (:text btn-item)
   :on-click (let [action (:action btn-item)]
               (if (nil? action)
                 #(dropdown-or-action btn-item true)
                 action))])

;; -------------------------
;; Views

(defn home-page []
  [:div
   [:h2 "Reagent Playground"]
   [:p "A groundbreaking, revolutionary app that does stuff."]
   [:div {:class "button-container"}
    (map (fn [btn] [:button
                    {:on-click #(dropdown-or-action btn false)}
                    (:text btn)]) action-btns)]])

;; -------------------------
;; Initialize app

(defn mount-root []
  (d/render [home-page] (.getElementById js/document "app")))

(defn ^:export init! []
  (mount-root))
