(ns reagent-test.ncbi
  (:require [cljs.core.async :refer [<! go]]
            [cljs-http.client :as http]
            [goog.string :as gstring]
            [goog.string.format]
            [goog.dom.xml :refer [loadXml]]))

(def base-url "https://eutils.ncbi.nlm.nih.gov/entrez/eutils")

(defn ncbi-db-search
  "Send search query to NCBI database, and get back a list of ID strings.
   [More info](https://www.ncbi.nlm.nih.gov/books/NBK25500/#_chapter1_Searching_a_Database_)

   Example Query: `science[journal]+AND+breast+cancer+AND+2008[pdat]`"
  [db-id query]
  (go (let [res (<! (http/get (gstring/format
                               "%s/esearch.fcgi?db=%s&term=%s"
                               base-url db-id query)))
            xml-doc (loadXml res)]
        (. xml-doc getElementByTagName "Id"))))

(defn ncbi-db-get-summary
  "Get summary by ID.
   [More info](https://www.ncbi.nlm.nih.gov/books/NBK25500/#_chapter1_Downloading_Document_Summaries_)"
  [db-id id]
  (go (let [res (<! (http/get (gstring/format
                              "%s/esummary.fcgi?db=%s&id=%s"
                               base-url db-id id)))
            xml-doc (loadXml res)]
        (js/console.log "hi"))))

(defn ncbi-search-gene [query] (ncbi-db-search "gene" query))
(defn ncbi-id-gene [query] (ncbi-db-search "gene" query))
